pub struct LogArgs {
pub log: Vec<Option<LogDestinationConfig>>,
}Fields
log: Vec<Option<LogDestinationConfig>>Log definition consisting of an optional log level filter, and a log destination. You can define this argument multiple times for multiple log destinations.
Logging can be disabled with --log none.
If combined with other log definitions, those will take precedence and logging will not be disabled.
The argument can be combined with a level filter to only log messages of a certain level or higher to that destination.
Format: destination | level_filter:destination
- level_filter = “ERROR” | “WARN” | “INFO” | “DEBUG” | “TRACE”
- destination = “stderr” | “syslog” | “file:path” | “none”
Examples:
--log syslog--log stderr--log file:/path/to/file--log INFO:stderr--log DEBUG:file:/path/to/file--log TRACE:syslog--log none
Implementations
Sourceimpl LogArgs
impl LogArgs
Sourcepub fn or_default(&self, default: LoggingConfig) -> LoggingConfig
pub fn or_default(&self, default: LoggingConfig) -> LoggingConfig
Build the LoggingConfig defined by the command line arguments from LogArgs.
If no --log argument is given, the default config is returned.